@@ -57,7 +57,7 @@ impl ToSVG for Drawing {
     fn to_svg(&self) -> Result<String, Box<dyn Error>> {
         let offset = -self.canvas_size() / 2.;
         Ok(format!(
-            r#"<svg viewBox="{offset_x} {offset_y} {max_x} {max_y}">{}</svg>"#,
+            r#"<svg width="{max_x}px" height="{max_y}px" viewBox="{offset_x} {offset_y} {max_x} {max_y}">{}</svg>"#,
             self.shapes().to_svg()?,
             // self.shapes()[0],
             offset_x = offset.x,
