@@ -101,10 +101,10 @@ impl ToSVG for Shape {
                 height = size.y,
                 href = match data {
                     ImageFormat::PNG(ref d) => {
-                        format!("image/png;base64,{}", base64::encode(d))
+                        format!("data:image/png;base64,{}", base64::encode(d))
                     }
                     ImageFormat::JPEG(ref d) => {
-                        format!("image/jpeg;base64,{}", base64::encode(d))
+                        format!("data:image/jpeg;base64,{}", base64::encode(d))
                     }
                 }
             )),
@@ -191,7 +191,7 @@ impl ToSVG for Color {
             Color::RGB { r, g, b } => {
                 Color::U32((*r as u32) << 16 | (*g as u32) << 8 | *b as u32).to_svg()
             }
-            Color::U32(c) => Ok(format!("#{:X?}", c)),
+            Color::U32(c) => Ok(format!("#{}", format!("{:#08X?}", c).split_at(2).1)),
         }
     }
 }
@@ -199,7 +199,7 @@ impl ToSVG for Color {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use dessin::{vec2, AddShape, Drawing};
+    use dessin::{vec2, Drawing};
 
     struct MyStruct;
     impl ToSVG for MyStruct {
@@ -269,5 +269,11 @@ mod tests {
 
         let u = Color::U32(0x12345678);
         assert_eq!(u.to_svg().unwrap(), "#12345678");
+
+        let red = Color::U32(0xFF0000);
+        assert_eq!(red.to_svg().unwrap(), "#FF0000");
+
+        let blue = Color::U32(0x0000FF);
+        assert_eq!(blue.to_svg().unwrap(), "#0000FF");
     }
 }
